package com.muyu.vehicle.model;


import com.muyu.web.domain.VehicleInfo;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;

/**
 * @author 牧鱼
 * @Classname VehicleData
 * @Description 车辆模拟数据对象
 * @Date 2021/8/5
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class VehicleData {
    /**
     * VIN
     */
    private String vin;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;

    /**
     * 速度
     */
    private String speed;

    /**
     * 里程
     */
    private BigDecimal mileage;

    /**
     * 档位
     */
    @Builder.Default
    private String gear = "P";

    /**
     * 电池剩余电量
     */
    private BigDecimal remainingBattery;

    /**
     * 电池电量
     */
    private BigDecimal batteryLevel;

    /**
     * 燃料消耗率
     */
    private String fuelConsumptionRate;

    private Map<String, String> dataMap = new HashMap<String, String>();

    /**
     * 存放值
     * @param key
     * @param value
     */
    public void putData(String key, String value) {
        dataMap.put(key, value);
    }

    /**
     * 获取值
     * @param key
     * @return
     */
    public String getData(String key) {
        return dataMap.get(key);
    }

    public String genValue(double start, double end) {
        Random random = new Random();
        return String.valueOf(random.nextDouble() * (end - start) + start);
    }

    public String getValue(String val , int valLength){
        if(val == null){
            val = "";
        }
        int length = val.length();
        if (length > valLength){
            return val.substring( 0 , valLength);
        }
        val = val + "0".repeat(valLength - length);
        return val;
    }

    /**
     * 汽车对象构造企业VIN
     * @param vehicleInfo 汽车对象
     * @return 汽车数据对象
     */
    public static VehicleData vehicleBuild (VehicleInfo vehicleInfo) {
        return VehicleData.builder()
                .vin(vehicleInfo.getVin())
                .gear("P")
                .remainingBattery(vehicleInfo.getRemainingBattery())
                .batteryLevel(vehicleInfo.getBatteryLevel())
                .mileage(vehicleInfo.getTotalMileage())
                .build();
    }
}
